@@ -35,7 +35,14 @@ sub get_session_id {
 }
 
 sub response_filter {
-    my ($self, $res, $session_id) = @_;
+    my ($self, $session_id, $res) = @_;
+    Carp::croak "missing session_id" unless $session_id;
+
+    $self->header_filter($session_id, $res);
+}
+
+sub header_filter {
+    my ($self, $session_id, $res) = @_;
     Carp::croak "missing session_id" unless $session_id;
 
     my $cookie = CGI::Cookie->new(
@@ -110,6 +117,10 @@ see also L<CGI::Simple::Cookie>.
 
 =over 4
 
+=item header_filter($res)
+
+header filter
+
 =item get_session_id
 
 =item response_filter
